"""
Base SCMRepository Class

Copyright (c) 2015 - 2024 Rob "N3X15" Nelson <nexisentertainment@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from typing import Optional


class SCMRepository:
    """Logical representation of a source code repository."""

    def __init__(
        self,
        path: str,
        quiet: bool = True,
        noisy_clone: bool = False,
        owner: Optional[str] = None,
        group: Optional[str] = None,
    ) -> None:
        self.path: str = path
        self.quiet: bool = quiet
        self.noisy_clone: bool = noisy_clone
        self.owner: Optional[str] = owner
        self.group: Optional[str] = group

    def CheckForUpdates(
        self,
        remote: str = "origin",
        branch: str = "HEAD",
        commit: Optional[str] = None,
        tag: Optional[str] = None,
        quiet: Optional[bool] = None,
    ) -> bool:
        return True

    def Update(self, cleanup: bool = False):
        return False
